library(testthat)
library(FSelectorRcpp)
library(Matrix)
library(Rcpp)
library(RcppArmadillo)
library(dplyr)
library(entropy)
library(lintr)

test_check("FSelectorRcpp")
